<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import InputSelect from '@/components/input-select'
import SelectShopUser from '@/components/coupon/select-shop-user'
import { couponForm, couponSearchForm, couponColumn } from '@/utils/coupon-form'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/v2/coupon/user/page',
        newUrl: 'flower/api/v2/coupon/user',
        viewUrl: 'flower/api/v2/coupon/user',
        viewOnPath: true,
        editUrl: 'flower/api/v2/coupon/user',
        editMethodType: 'put',
        editOnPath: true,
        deleteUrl: 'flower/api/v2/coupon/user',
        deleteMethodType: 'delete',
        deleteOnPath: true,
        dialogNeedRequest: true,
        canEdit: (row) => row.status === 'inactive' || row.status === 'expired',
        canDelete: (row) =>
          row.status === 'inactive' || row.status === 'expired',
        onResetView: (row) => {
          this.$router.push(`${this.$route.path}/${row.id}`)
        },
        operationAttrs: {
          width: 200,
          fixed: 'right',
        },
        columns: [
          ...couponColumn(),
          { label: '发放时间', prop: 'usageStartDate', minWidth: 180 },
          {
            label: '有效期',
            formatter: (row) =>
              row.usageStartDate
                ? `${row.usageStartDate} ~ ${row.usageEndDate || ''}`
                : '',
            minWidth: 400,
          },
          { label: '状态', prop: 'statusName', minWidth: 120 },
          { label: '操作人', prop: 'createByName', minWidth: 120 },
        ],
        searchForm: [
          {
            type: 'row',
            items: [...couponSearchForm()],
          },
        ],
        form: [
          ...couponForm(),
          {
            label: '发放后有效期：',
            id: 'usageTimeNum',
            component: InputSelect,
            commonRules: true,
            commonFormat: true,
            commonFormatProps: ['usageTimeNum', 'usageTimeType'],
            el: {
              inputAttrs: {
                min: 1,
                precision: 0,
                controls: false,
              },
              selectAttrs: {
                code: 'COUPON_USAGE_TIME_TYPE',
              },
            },
          },
          {
            label: '领取用户：',
            id: 'pointCostomIdList',
            component: SelectShopUser,
            rules: { required: true, message: '请选择领取用户' },
            inputFormat: (row) => {
              if ('customerList' in row) {
                return row.customerList
              }
            },
            outputFormat: (val) => {
              return val?.length ? val.map((i) => i.id) : []
            },
            forceDisabled: true,
          },
        ],
        extraButtons: [
          {
            text: '发布',
            show: (row) =>
              row.status === 'inactive' || row.status === 'expired',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要发布吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/api/v2/coupon/user/active/${row.id}`,
                  { method: 'put' }
                )
                if (code === 0) {
                  this.$message.success('发布成功')
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '下架',
            show: (row) => row.status === 'active',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要下架吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/api/v2/coupon/user/expire/${row.id}`,
                  { method: 'put' }
                )
                if (code === 0) {
                  this.$message.success('下架成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '用户优惠券',
    }
  },
}
</script>
